import pytest

from test_utils import add_data, can_use_gsp_read, cannot_use_sparql_update, cannot_use_gsp_write, \
    can_use_sparql_update, can_use_gsp_write, can_use_sparql_query

DATASET_NAME = "dalia"


class TestDaliaDatasetRead:
    @pytest.mark.parametrize("endpoint_name", ["", "query", "sparql"])
    def test_can_use_sparql_query(self, fuseki_url, endpoint_name):
        add_data(f"{fuseki_url}/{DATASET_NAME}/update")

        assert can_use_sparql_query(fuseki_url, DATASET_NAME, endpoint_name)

    @pytest.mark.parametrize("endpoint_name", ["", "get", "data"])
    def test_can_use_gsp_get(self, fuseki_url, endpoint_name):
        add_data(f"{fuseki_url}/{DATASET_NAME}/update")

        assert can_use_gsp_read(fuseki_url, DATASET_NAME, endpoint_name)

    @pytest.mark.parametrize("endpoint_name", ["query", "sparql", "get", "data"])
    def test_endpoints_are_not_writeable_with_sparql_update(self, fuseki_url, endpoint_name):
        assert cannot_use_sparql_update(fuseki_url, DATASET_NAME, endpoint_name)

    @pytest.mark.parametrize("endpoint_name", ["query", "sparql", "get", "update"])
    def test_endpoints_are_not_writeable_with_gsp(self, fuseki_url, endpoint_name):
        assert cannot_use_gsp_write(fuseki_url, DATASET_NAME, endpoint_name)


@pytest.mark.parametrize("endpoint_name", ["", "update"])
def test_endpoints_are_writeable_with_sparql_update(fuseki_url, endpoint_name):
    assert can_use_sparql_update(fuseki_url, DATASET_NAME, endpoint_name)


@pytest.mark.parametrize("endpoint_name", ["", "data"])
def test_endpoints_are_writeable_with_gsp(fuseki_url, endpoint_name):
    assert can_use_gsp_write(fuseki_url, DATASET_NAME, endpoint_name)
