import pytest
from rdflib.plugins.stores.sparqlstore import SPARQLStore

from test_utils import can_use_sparql_query, cannot_use_gsp_write, \
    cannot_use_sparql_update, can_use_gsp_read

DATASET_NAME = "ontologies"


class TestOntologiesDataset:
    @pytest.mark.parametrize("endpoint_name", ["", "query", "sparql", "get"])
    def test_dataset_is_not_writeable_with_gsp(self, fuseki_url, endpoint_name):
        assert cannot_use_gsp_write(fuseki_url, DATASET_NAME, endpoint_name)

    @pytest.mark.parametrize("endpoint_name", ["", "query", "sparql", "get"])
    def test_dataset_is_not_writeable_with_sparql_update(self, fuseki_url, endpoint_name):
        assert cannot_use_sparql_update(fuseki_url, DATASET_NAME, endpoint_name)

    @pytest.mark.parametrize("endpoint_name", ["", "query", "sparql"])
    def test_can_use_sparql_query(self, fuseki_url, endpoint_name):
        assert can_use_sparql_query(fuseki_url, DATASET_NAME, endpoint_name)

    @pytest.mark.parametrize("endpoint_name", ["", "get"])
    def test_can_use_gsp_get(self, fuseki_url, endpoint_name):
        assert can_use_gsp_read(fuseki_url, DATASET_NAME, endpoint_name)
